# Canaveral CLI

This Project uses [Typer](https://typer.tiangolo.com/) for the CLI functionality and [InquirerPy](https://inquirerpy.readthedocs.io/en/latest/index.html#) for the parameter selection

## Run it
Working with virtual envs in Python:
- https://realpython.com/python-virtual-environments-a-primer
- https://aaronlelevier.github.io/virtualenv-cheatsheet/

```bash
$ python3 -m venv venv --prompt="canaveral-env"
$ source venv/bin/activate
(canaveral-env) $ 
(canaveral-env) $ deactivate
$ 
$ pip install -r requirements.txt
$ OR
$ python -m pip install -r requirements.txt
```

## How to contribuite
Project layout to adhere to:
- https://realpython.com/python-application-layouts/#command-line-application-layouts

## Internal Notes

Devscope Internal notes and documentation avaible at [Canaveral](https://devscope365.sharepoint.com/sites/academy/_layouts/OneNote.aspx?id=%2Fsites%2Facademy%2FSiteAssets%2FAcademy%20Notebook&wd=target%282023.one%7C1069493A-33E1-4F4C-8D77-28AA9AE54494%2FCanaveral%20CLI%7CF359B855-A8C4-4DB9-B416-CA0D700F2904%2F%29)
